@@ -56,6 +56,8 @@ FILTER_WAV_FILES = ["WAV files (*.wav)"]
 APP_NAME = f"{corrscope.app_name} {corrscope.__version__}"
 APP_DIR = Path(__file__).parent
 
+PATH_uri = qc.QUrl.fromLocalFile(paths.PATH_dir)
+
 
 def res(file: str) -> str:
     return str(APP_DIR / file)
@@ -195,18 +197,31 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
             self.on_separate_render_dir_toggled
         )
 
+        self.action_open_config_dir.triggered.connect(self.on_open_config_dir)
+
         self.actionNew.triggered.connect(self.on_action_new)
         self.actionOpen.triggered.connect(self.on_action_open)
         self.actionSave.triggered.connect(self.on_action_save)
         self.actionSaveAs.triggered.connect(self.on_action_save_as)
         self.actionPreview.triggered.connect(self.on_action_preview)
         self.actionRender.triggered.connect(self.on_action_render)
+
+        self.actionWebsite.triggered.connect(self.on_action_website)
         self.actionHelp.triggered.connect(self.on_action_help)
+
         self.actionExit.triggered.connect(qw.QApplication.closeAllWindows)
 
         # Initialize CorrScope-thread attribute.
         self.corr_thread: Optional[CorrThread] = None
 
+        # Setup UI.
+        self.model = ConfigModel(template_config())
+        self.model.edited.connect(self.on_model_edited)
+        # Calls self.on_gui_edited() whenever GUI widgets change.
+        map_gui(self, self.model)
+
+        self.model.update_widget["render_stereo"].append(self.on_render_stereo_changed)
+
         # Bind config to UI.
         if isinstance(cfg_or_path, Config):
             self.load_cfg(cfg_or_path, None)
@@ -243,6 +258,11 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
     channel_view: "ChannelTableView"
     channelsGroup: qw.QGroupBox
 
+    def on_render_stereo_changed(self):
+        self.layout__stereo_orientation.setEnabled(
+            self.model.cfg.render_stereo is Flatten.Stereo
+        )
+
     # Closing active document
 
     def _cancel_render_if_active(self, title: str) -> bool:
@@ -355,13 +375,7 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
         self.load_title()
         self.left_tabs.setCurrentIndex(0)
 
-        if self.model is None:
-            self.model = ConfigModel(cfg)
-            self.model.edited.connect(self.on_model_edited)
-            # Calls self.on_gui_edited() whenever GUI widgets change.
-            map_gui(self, self.model)
-        else:
-            self.model.set_cfg(cfg)
+        self.model.set_cfg(cfg)
 
         self.channel_model = ChannelModel(cfg.channels)
         # Calling setModel again disconnects previous model.
@@ -395,6 +409,8 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
     channelDown: "ShortcutButton"
 
     action_separate_render_dir: qw.QAction
+    action_open_config_dir: qw.QAction
+
     # Loading mainwindow.ui changes menuBar from a getter to an attribute.
     menuBar: qw.QMenuBar
     actionNew: qw.QAction
@@ -421,6 +437,10 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
         else:
             self.pref.render_dir = ""
 
+    def on_open_config_dir(self):
+        appdata_uri = qc.QUrl.fromLocalFile(str(paths.appdata_dir))
+        QDesktopServices.openUrl(appdata_uri)
+
     def on_channel_add(self):
         wavs = get_open_file_list(
             self, "Add audio channels", self.pref.file_dir_ref, FILTER_WAV_FILES
@@ -623,6 +643,11 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
         return self.model.cfg
 
     # Misc.
+    @qc.pyqtSlot()
+    def on_action_website(self):
+        website_url = r"https://github.com/corrscope/corrscope/"
+        QDesktopServices.openUrl(qc.QUrl(website_url))
+
     @qc.pyqtSlot()
     def on_action_help(self):
         help_url = r"https://corrscope.github.io/corrscope/"
@@ -1113,11 +1138,11 @@ class ChannelModel(qc.QAbstractTableModel):
             return True
         return False
 
-    """So if I understood it correctly you want to reorder the columns by moving the 
-    headers and then want to know how the view looks like. I believe ( 90% certain ) 
-    when you reorder the headers it does not trigger any change in the model! and 
-    then if you just start printing the data of the model you will only see the data 
-    in the order how it was initially before you swapper/reordered some column with 
+    """So if I understood it correctly you want to reorder the columns by moving the
+    headers and then want to know how the view looks like. I believe ( 90% certain )
+    when you reorder the headers it does not trigger any change in the model! and
+    then if you just start printing the data of the model you will only see the data
+    in the order how it was initially before you swapper/reordered some column with
     the header. """
 
     def insertRows(self, row: int, count: int, parent=QModelIndex()) -> bool:
@@ -1195,15 +1220,15 @@ class DownloadFFmpegActivity:
     ffmpeg_url = paths.get_ffmpeg_url()
     can_download = bool(ffmpeg_url)
 
-    path_uri = qc.QUrl.fromLocalFile(paths.PATH_dir).toString()
-
     required = (
         f"FFmpeg+FFplay must be in PATH or "
-        f'<a href="{path_uri}">corrscope folder</a> in order to use corrscope.<br>'
+        f'<a href="{PATH_uri.toString()}">corrscope PATH</a> in order to use corrscope.<br>'
     )
 
     ffmpeg_template = required + (
-        f'Download ffmpeg from <a href="{ffmpeg_url}">{ffmpeg_url}</a>.'
+        f'Download ffmpeg from <a href="{ffmpeg_url}">this link</a>, '
+        f"open in 7-Zip and navigate to the ffmpeg-.../bin folder, "
+        f"and copy all .exe files to the folder above."
     )
     fail_template = required + "Cannot download FFmpeg for your platform."
 
