@@ -250,7 +250,7 @@ class MainWindow(QWidget):
                     tr("Stereo Orientation"),
                     BoundComboBox,
                     name="layout__stereo_orientation",
-                ):
+                ) as self.layout__stereo_orientation:
                     pass
 
                 with add_row(
@@ -441,40 +441,55 @@ class MainWindow(QWidget):
         self.actionExit = QAction(MainWindow)
         self.actionPreview = QAction(MainWindow)
         self.actionRender = QAction(MainWindow)
+
+        self.actionWebsite = create_element(
+            QAction, MainWindow, text=tr("corrscope Website")
+        )
         self.actionHelp = create_element(QAction, MainWindow, text=tr("Help"))
-        self.action_separate_render_dir = QAction(MainWindow)
-        self.action_separate_render_dir.setCheckable(True)
+
+        self.action_separate_render_dir = create_element(
+            QAction, MainWindow, text=tr("&Separate Render Folder"), checkable=True
+        )
+        self.action_open_config_dir = create_element(
+            QAction, MainWindow, text=tr("Open &Config Folder")
+        )
 
         # Setup menu_bar
         assert s.widget is MainWindow
         with set_menu_bar(s) as self.menuBar:
             with append_menu(s) as self.menuFile:
-                self.menuFile.addAction(self.actionNew)
-                self.menuFile.addAction(self.actionOpen)
-                self.menuFile.addAction(self.actionSave)
-                self.menuFile.addAction(self.actionSaveAs)
-                self.menuFile.addSeparator()
-                self.menuFile.addAction(self.actionPreview)
-                self.menuFile.addAction(self.actionRender)
-                self.menuFile.addSeparator()
-                self.menuFile.addAction(self.actionExit)
+                w = self.menuFile
+                w.addAction(self.actionNew)
+                w.addAction(self.actionOpen)
+                w.addAction(self.actionSave)
+                w.addAction(self.actionSaveAs)
+                w.addSeparator()
+                w.addAction(self.actionPreview)
+                w.addAction(self.actionRender)
+                w.addSeparator()
+                w.addAction(self.actionExit)
 
             with append_menu(s) as self.menuTools:
-                self.menuTools.addAction(self.action_separate_render_dir)
+                w = self.menuTools
+                w.addAction(self.action_separate_render_dir)
+                w.addSeparator()
+                w.addAction(self.action_open_config_dir)
 
-            with append_menu(s, title=tr("&Help")) as w:
-                self.menuHelp = w
+            with append_menu(s, title=tr("&Help")) as self.menuHelp:
+                w = self.menuHelp
+                w.addAction(self.actionWebsite)
                 w.addAction(self.actionHelp)
 
         # Setup toolbar
         with add_toolbar(s, Qt.TopToolBarArea) as self.toolBar:
-            self.toolBar.addAction(self.actionNew)
-            self.toolBar.addAction(self.actionOpen)
-            self.toolBar.addAction(self.actionSave)
-            self.toolBar.addAction(self.actionSaveAs)
-            self.toolBar.addSeparator()
-            self.toolBar.addAction(self.actionPreview)
-            self.toolBar.addAction(self.actionRender)
+            w = self.toolBar
+            w.addAction(self.actionNew)
+            w.addAction(self.actionOpen)
+            w.addAction(self.actionSave)
+            w.addAction(self.actionSaveAs)
+            w.addSeparator()
+            w.addAction(self.actionPreview)
+            w.addAction(self.actionRender)
 
     # noinspection PyUnresolvedReferences
     def retranslateUi(self, MainWindow):
@@ -520,7 +535,6 @@ class MainWindow(QWidget):
         self.actionPreview.setShortcut(tr("Ctrl+P"))
         self.actionRender.setText(tr("&Render to Video"))
         self.actionRender.setShortcut(tr("Ctrl+R"))
-        self.action_separate_render_dir.setText(tr("&Separate Render Folder"))
 
 
 from corrscope.gui.model_bind import (
